@@ -1,10 +1,8 @@
-// Copyright (C) 2014-2018 Manuel Schneider
+// Copyright (C) 2014-2024 Manuel Schneider
 
 #pragma once
-#include <QJsonObject>
 #include <QTimer>
-
-namespace Core {
+class QJsonObject;
 
 class Telemetry final
 {
@@ -12,16 +10,13 @@ public:
 
     Telemetry();
 
-    void enable(bool enable);
-    bool isEnabled() const;
     QJsonObject buildReport();
+    QString buildReportString();
 
 private:
 
     void trySendReport();
 
-    QTimer timer_;
+    QTimer timer;
 
 };
-
-}
